#define MAX_LIGHTS 2

attribute vec4 inVertexPosition;
attribute vec4 inVertexColor;
attribute vec4 inTexCoord0;
attribute vec3 inVertexNormal;
attribute vec3 inVertexTangent;
attribute vec3 inVertexBinormal;

uniform highp mat4 uMvpMatrix;

uniform highp vec4 uLightPos0;
uniform highp vec4 uLightPos1;
uniform vec4 uLightColor0;
uniform vec4 uLightColor1;

varying vec2 varTexCoord;
varying vec3 varLightVector[MAX_LIGHTS];
varying vec4 varLightColor[MAX_LIGHTS];

void main(void)
{
	// transform position to clip space
	gl_Position = uMvpMatrix * inVertexPosition;
	
	// vertex - lightpositions
	vec4 tempLightVector0 = uLightPos0 - inVertexPosition;
	vec4 tempLightVector1 = uLightPos1 - inVertexPosition;
	
	// transform the light vector 1 with U, V, W
	varLightVector[0].x = dot(inVertexTangent,  tempLightVector0.xyz);
	varLightVector[0].y = dot(inVertexBinormal, tempLightVector0.xyz);
	varLightVector[0].z = dot(inVertexNormal,   tempLightVector0.xyz);

	
	// transform the light vector 2 with U, V, W
	varLightVector[1].x = dot(inVertexTangent,  tempLightVector1.xyz);
	varLightVector[1].y = dot(inVertexBinormal, tempLightVector1.xyz);
	varLightVector[1].z = dot(inVertexNormal,   tempLightVector1.xyz);

	// calculate attenuation of light 0
	varLightColor[0].w = 0.0;
	varLightColor[0].x = dot(tempLightVector0, tempLightVector0);
	varLightColor[0].x *= uLightColor0.w;
	varLightColor[0] = vec4(inversesqrt(varLightColor[0].x));
	varLightColor[0] *= uLightColor0;
	
	// normalize light vector 0
	varLightVector[0] = normalize(varLightVector[0]);
	
	// calculate attenuation of light 1
	varLightColor[1].w = 0.0;
	varLightColor[1].x = dot(tempLightVector1, tempLightVector1);
	varLightColor[1].x *= uLightColor1.w;
	varLightColor[1] = vec4(inversesqrt(varLightColor[1].x));
	varLightColor[1] *= uLightColor1;
	
	// normalize light vector 1
	varLightVector[1] = normalize(varLightVector[1]);
	
	// move out texture coordinates and original alpha value
	varTexCoord = inTexCoord0.xy;
	varLightColor[0].a = inVertexColor.a;
}