#define MAX_LIGHTS 2

precision mediump float;

uniform sampler2D texture0;
uniform sampler2D texture1;

uniform vec4 uLightDiffuse[MAX_LIGHTS];
uniform float uHeightScale;

varying vec2 varTexCoord;
varying vec3 varLightVector[MAX_LIGHTS];
varying vec4 varLightColor[MAX_LIGHTS];
varying vec3 varEyeVector;

void main(void)
{
	// fetch color and normal map
	vec4 normalMap = texture2D(texture1, varTexCoord.xy) *  2.0 - 1.0;

	// height = height * scale
	// TODO - agalarneau : commenting next line gives a cool effect - need to check this out later on
	normalMap *= uHeightScale;
	
	// calculate new texture coord: height * eye + oldTexCoord
	vec2 offset = varEyeVector.xy * normalMap.w + varTexCoord.xy;

	// fetch new textures
	vec4 colorMap  = texture2D(texture0, offset);
	normalMap = normalize(texture2D(texture1, offset) * 2.0 - 1.0); 
	
	// calculate color of light 0
	vec4 color = clamp(varLightColor[0], 0.0, 1.0) * dot(normalMap.xyz, normalize(varLightVector[0].xyz));
	
	// calculate color of light 1
	color += clamp(varLightColor[1], 0.0, 1.0) * dot(normalMap.xyz, normalize(varLightVector[1].xyz));

	//luminance * base color
	color *= colorMap;
	color.a = varLightColor[0].a;
	
	gl_FragColor = color;
}
